Class: BaseAction
- Inherits:
-
Object
- Object
- BaseAction
- Includes:
- FileUtils
- Defined in:
- lib/lockr/action/base.rb
Direct Known Subclasses
Instance Method Summary collapse
-
#load_from_vault(vault) ⇒ Object
loads the datastructure for the password sets from the file it looks like this:.
- #save_to_vault(storelist, vault) ⇒ Object
Methods included from FileUtils
calculate_sha512_hash, copy, load_obj_yaml, rotate_file, store_obj_yaml
Instance Method Details
#load_from_vault(vault) ⇒ Object
loads the datastructure for the password sets from the file it looks like this:
pwd_directory = {
:id => {
:enc => 'encrypted password store list',
:salt => 'salt for decryption'
}
}
decrypted_store_list =
:username => PasswordStore
25 26 27 |
# File 'lib/lockr/action/base.rb', line 25 def load_from_vault( vault) FileUtils.load_obj_yaml( vault) end |
#save_to_vault(storelist, vault) ⇒ Object
8 9 10 |
# File 'lib/lockr/action/base.rb', line 8 def save_to_vault( storelist, vault) FileUtils.store_obj_yaml( vault, storelist) end |